package com.inspect.img.mapper;

import com.inspect.img.domain.InspectionReportImg;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface InspectionReportImgMapper {
    InspectionReportImg selectInspectionReportImgByLineId(Long lineId);

    List<InspectionReportImg> selectInspectionReportImgList(InspectionReportImg reportImg);

    int insertInspectionReportImg(InspectionReportImg reportImg);

    int updateInspectionReportImg(InspectionReportImg reportImg);

    int deleteInspectionReportImgByLineId(Long lineId);

    int deleteInspectionReportImgByLineIds(Long[] lineIds);

    int batchInsertInspectionReportImg(List<InspectionReportImg> reportImgList);

    List<InspectionReportImg> selectByReportInfoIds(@Param("lineIds") List<String> lineIds);
}
